@@ -180,16 +180,20 @@ def _simulation_execute_operation(
 
     # Wait for the operation to be completed in backend
     current_operation_status: Dict[str, Any] = {}
+    display_idx = 0
     while True:
         # Sleep before next iteration
-        time.sleep(2)
+        time.sleep(0.5)
 
-        logger.info(
-            "  [+] Currently executing operation '{}' on "
-            "simulation ID '{}', with task id {}...".format(
-                operation, id_simulation, task_identifier
+        # Do not display debug info at each loop iteraion
+        if display_idx % 10 == 0:
+            logger.info(
+                "  [+] Currently executing operation '{}' on "
+                "simulation ID '{}', with task id {}...".format(
+                    operation, id_simulation, task_identifier
+                )
             )
-        )
+        display_idx += 1
 
         result = _get(uri_get_status)
         if result.status_code != 200:
@@ -1572,6 +1576,24 @@ def update_node(node_id: int, node_dict: dict) -> Any:
     return result.json()
 
 
+def get_node_default_gateway(id_node: int) -> Optional[str]:
+    """Retrieve node default gateway, which can either be an IP address
+    of the form xx.xx.xx.xx or None if no gateway is set.
+
+    """
+
+    result = _get(f"/node/{id_node}/default_gateway")
+
+    if result.status_code != 200:
+        _handle_error(
+            result, "Cannot retrieve node default gateway from IT Simulation API"
+        )
+
+    default_gateway = result.json()
+
+    return default_gateway
+
+
 def get_node_statistics_by_id(id_node: int) -> Any:
     """
     Return aggregated statistics from CPU, memory, block devices and network interfaces.
@@ -1637,7 +1659,7 @@ def node_exec(id_node: int, command: str) -> Any:
         or status_key not in result.json()
         or result.json()[status_key] != "STARTED"
     ):
-        _handle_error(result, "Cannot initiate exec command fom IT Simulation API")
+        _handle_error(result, "Cannot initiate exec command from IT Simulation API")
 
     logger.info(f"[+] Executing command '{command}' for node '{id_node}'...")
 
@@ -1700,7 +1722,7 @@ def node_memorydump(id_node: int) -> Any:
         or status_key not in result.json()
         or result.json()[status_key] != "STARTED"
     ):
-        _handle_error(result, "Cannot initiate node memory dump fom core API")
+        _handle_error(result, "Cannot initiate node memory dump from core API")
 
     logger.info("[+] Initialized memory dump of node '{}'...".format(id_node))
 
@@ -1714,7 +1736,7 @@ def node_memorydump(id_node: int) -> Any:
         result = _get(f"/node/{id_node}/memorydump_status")
 
         if result.status_code != 200:
-            _handle_error(result, "Cannot get status of node memory dump fom core API")
+            _handle_error(result, "Cannot get status of node memory dump from core API")
 
         result_json = result.json()
         if not (
@@ -2261,6 +2283,42 @@ def unpause_simulation(id_simulation: int) -> None:
     _simulation_execute_operation("get", "unpause", id_simulation, "UNPAUSING")
 
 
+def create_backup_simulation(
+    id_simulation: int,
+    nodes: Optional[List[str]] = None,
+) -> None:
+    """Create backup of a simulation. It is possible to specify the nodes
+    to backup. By default, all nodes are backed up.
+
+    """
+
+    if nodes is None:
+        nodes = []
+    post_data = {"nodes": nodes}
+
+    _simulation_execute_operation(
+        "post", "create_backup", id_simulation, "PREPARING", post_data=post_data
+    )
+
+
+def restore_backup_simulation(
+    id_simulation: int,
+    nodes: Optional[List[str]] = None,
+) -> None:
+    """Restore backup of a simulation. It is possible to specify the nodes
+    to restore. By default, all nodes are restored.
+
+    """
+
+    if nodes is None:
+        nodes = []
+    post_data = {"nodes": nodes}
+
+    _simulation_execute_operation(
+        "post", "restore_backup", id_simulation, "PREPARING", post_data=post_data
+    )
+
+
 def halt_simulation(
     id_simulation: int, nodes: Optional[List[str]] = None
 ) -> Optional[uuid.UUID]:
@@ -2305,10 +2363,10 @@ def clone_simulation(id_simulation: int) -> int:
 def net_create_probe(  # noqa: C901
     id_simulation: int,
     simu_nodes: Dict,
-    iface: str,
-    pcap: bool,
-    filter: str,
-    direction: str,
+    iface: Optional[str] = None,
+    pcap: Optional[bool] = False,
+    filter: Optional[str] = "",
+    direction: Optional[str] = "both",
 ) -> int:
     """Create a new probe and configure his network collections points.
 
@@ -2324,7 +2382,7 @@ def net_create_probe(  # noqa: C901
     :type iface: :class:`str`, ex : dummy0
     :type pcap: :class:`bool`, ex : true
     :type filter: :class:`str`, ex : tcp port 80
-    :type filter: :class:`str`, ex : ingress
+    :type direction: :class:`str`, ex : ingress
     """
 
     network_interfaces = []
