@@ -28,6 +28,7 @@ import time
 from tempfile import TemporaryDirectory
 from typing import Any
 from typing import List
+from typing import Optional
 from typing import Tuple
 
 import requests
@@ -235,24 +236,36 @@ def provisioning_execute(
 
 
 def provisioning_ansible(
-    id_simulation: int = None,
-    machines_file: str = None,
-    playbook_path: str = None,
-    target_roles: List[str] = [],
-    target_system_types: List[str] = [],
-    target_operating_systems: List[str] = [],
-    target_names: List[str] = [],
-    host_vars: List[str] = [],
-    extra_vars: str = None,
+    id_simulation: Optional[int] = None,
+    machines_file: Optional[str] = None,
+    playbook_path: Optional[str] = None,
+    target_roles: Optional[List[str]] = None,
+    target_system_types: Optional[List[str]] = None,
+    target_operating_systems: Optional[List[str]] = None,
+    target_names: Optional[List[str]] = None,
+    host_vars: Optional[List[str]] = None,
+    extra_vars: Optional[str] = None,
+    gather_facts: Optional[bool] = None,
     debug: bool = False,
     wait: bool = True,
     timeout: int = 3600,
-) -> Tuple[bool, str]:
+) -> Tuple[bool, Optional[str]]:
     """Apply ansible playbooks on specified target(s). The ``wait`` parameter defines if
     the function wait for task to complete or not.
 
     """
 
+    if target_roles is None:
+        target_roles = []
+    if target_system_types is None:
+        target_system_types = []
+    if target_operating_systems is None:
+        target_operating_systems = []
+    if target_names is None:
+        target_names = []
+    if host_vars is None:
+        host_vars = []
+
     if playbook_path is None:
         raise Exception("provisioning_file parameter cannot be None")
 
@@ -268,7 +281,9 @@ def provisioning_ansible(
     else:
         log_suffix = f"on machines '{machines_file}'"
 
-    logger.info(f"[+] Starting provisioning ansible playbook(s) {log_suffix}")
+    logger.info(
+        f"[+] Starting provisioning ansible playbook(s) {playbook_path} {log_suffix}"
+    )
 
     if id_simulation:
         # Check simulation is running
@@ -283,6 +298,21 @@ def provisioning_ansible(
                     id_simulation=id_simulation, current_status=simulation_status
                 )
             )
+
+        # Remove non-active nodes from target_names, as they are not running on the simulation
+        if len(target_names) > 0:
+            new_target_names = []
+            simulation_nodes = core_api.fetch_nodes(id_simulation)
+            for node in simulation_nodes:
+                if node["name"] in target_names and node["active"] is True:
+                    new_target_names.append(node["name"])
+
+            logger.info(f"[+] Initial target names: {target_names}")
+            target_names = new_target_names
+            logger.info(
+                f"[+] Updated target names according to active nodes on the simulation: {target_names}"
+            )
+
         machines_yaml = None
     else:
         # Validate input file
@@ -291,6 +321,16 @@ def provisioning_ansible(
         # Open and read YAML input files
         machines_yaml = _read_yaml_file(machines_file)
 
+    # Double check if targets are not empty
+    if (
+        len(target_roles) == 0
+        and len(target_system_types) == 0
+        and len(target_operating_systems) == 0
+        and len(target_names) == 0
+    ):
+        logger.warning("Target lists are empty. No provisioning will be done.")
+        return (False, None)
+
     data = {
         "id_simulation": id_simulation,
         "machines_yaml": machines_yaml,
@@ -300,6 +340,7 @@ def provisioning_ansible(
         "target_operating_systems": target_operating_systems,
         "target_names": target_names,
         "host_vars": host_vars,
+        "gather_facts": gather_facts,
         "debug": debug,
     }
 
@@ -468,16 +509,21 @@ def provisioning_wait_until_complete(
     current_status = ""
 
     finished = False
+    display_idx = 0
     while not (finished or (time.time() - start_time) > timeout):
-        time.sleep(2)
+        time.sleep(1)
         current_time = time.time()
         elapsed = int(current_time - start_time)
-        if log_suffix is not None:
-            logger.info(
-                f"   [+] Currently provisioning {log_suffix} for {elapsed} seconds (timeout at {timeout} seconds)"
-            )
-        else:
-            logger.info(f"   [+] Currently provisioning for {elapsed} seconds")
+
+        # Do not display debug info at each loop iteraion
+        if display_idx % 10 == 0:
+            if log_suffix is not None:
+                logger.info(
+                    f"   [+] Currently provisioning {log_suffix} for {elapsed} seconds (timeout at {timeout} seconds)"
+                )
+            else:
+                logger.info(f"   [+] Currently provisioning for {elapsed} seconds")
+        display_idx += 1
 
         result = _post("/provisioning/status_provisioning", data={"task_id": task_id})
         result.raise_for_status()
