@@ -21,13 +21,12 @@ from pydantic import validator
 
 from .node import Node
 from .node import TypeEnum
-from cr_api_client.topology.validator.common import PositiveEqualInt
 
 
 class NetworkConfig(BaseModel):
-    ip: Optional[Union[
-        IPvAnyInterface, Literal["dynamic"]
-    ]]  # If the ip is not provided it should be dynamic, however it can be left empty in the yaml file
+    ip: Optional[
+        Union[IPvAnyInterface, Literal["dynamic"]]
+    ]  # If the ip is not provided it should be dynamic, however it can be left empty in the yaml file
     mac: Optional[str] = Field(regex="^(?:[0-9A-Fa-f]{2}[:-]){5}(?:[0-9A-Fa-f]{2})$")
 
 
