@@ -271,7 +271,7 @@ def user_activity_status(id_simulation: int, id_user_activity: str) -> None:
         raise Exception("Issue when getting user activity status: '{}'".format(e))
 
 
-def all_activities_status(id_simulation: int) -> None:
+def all_activities_status(id_simulation: int) -> str:
     """Get all user activities status on targeted simulation."""
 
     try:
